@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Circle;
 
-$Map::Tube::London::Line::Circle::VERSION   = '1.37';
+$Map::Tube::London::Line::Circle::VERSION   = '1.38';
 $Map::Tube::London::Line::Circle::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Circle - London Tube Map: Circle Line.
 
 =head1 VERSION
 
-Version 1.37
+Version 1.38
 
 =head1 DESCRIPTION
 
@@ -33,9 +33,9 @@ London Tube Map: Circle Line.
     | Edgware Road             | Paddington, Baker Street                        |
     | Baker Street             | Edgware Road, Great Portland Street             |
     | Great Portland Street    | Baker Street, Euston Square                     |
-    | Euston Square            | Great Portland Street, King's Cross St. Pancras |
-    | King's Cross St. Pancras | Euston Square, Farringdon                       |
-    | Farringdon               | King's Cross St. Pancras, Barbican              |
+    | Euston Square            | Great Portland Street, King's Cross St Pancras |
+    | King's Cross St Pancras  | Euston Square, Farringdon                       |
+    | Farringdon               | King's Cross St Pancras, Barbican              |
     | Barbican                 | Farringdon, Moorgate                            |
     | Moorgate                 | Barbican, Liverpool Street                      |
     | Liverpool Street         | Moorgate, Aldgate                               |
@@ -49,7 +49,7 @@ London Tube Map: Circle Line.
     | Embankment               | Temple, Westminster                             |
     | Westminster              | Embankment, St Jame's Park                      |
     | St James's Park          | Westminster, Victoria                           |
-    | Victoria                 | St. James Park, Sloane Square                   |
+    | Victoria                 | St James's Park, Sloane Square                   |
     | Sloane Square            | Victoria, South Kensington                      |
     | South Kensington         | Sloane Square, Gloucester Road                  |
     | Gloucester Road          | South Kensington, High Street Kensington        |
@@ -121,7 +121,7 @@ London Tube Map: Circle Line.
 =item * The station "High Street Kensington" is also part of
           L<District Line|Map::Tube::London::Line::District>
 
-=item * The station "King's Cross St. Pancras" is also part of
+=item * The station "King's Cross St Pancras" is also part of
           L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
         | L<Northern Line|Map::Tube::London::Line::Northern>
@@ -172,7 +172,7 @@ London Tube Map: Circle Line.
           L<District Line|Map::Tube::London::Line::District>
         | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
 
-=item * The station "St. James's Park" is also part of
+=item * The station "St James's Park" is also part of
           L<District Line|Map::Tube::London::Line::District>
 
 =item * The station "Temple" is also part of
